@@ -31,7 +31,7 @@ using namespace miral;
 
 namespace
 {
-int const title_bar_height = 10;
+int const title_bar_height = 12;
 }
 
 TitlebarWindowManagerPolicy::TitlebarWindowManagerPolicy(
@@ -120,6 +120,9 @@ bool TitlebarWindowManagerPolicy::handle_pointer_event(MirPointerEvent const* ev
 
 void TitlebarWindowManagerPolicy::end_resize()
 {
+    if (!resizing  && !pinching)
+        return;
+
     if (auto window = tools.active_window())
     {
         auto& window_info = tools.info_for(window);
@@ -272,9 +275,9 @@ void TitlebarWindowManagerPolicy::advise_new_window(WindowInfo const& window_inf
         auto const parent = window_info.parent();
 
         if (tools.active_window() == parent)
-            titlebar_provider->paint_titlebar_for(parent, 0xFF);
+            titlebar_provider->paint_titlebar_for(tools.info_for(parent), 0xFF);
         else
-            titlebar_provider->paint_titlebar_for(parent, 0x3F);
+            titlebar_provider->paint_titlebar_for(tools.info_for(parent), 0x3F);
     }
 }
 
@@ -290,14 +293,14 @@ void TitlebarWindowManagerPolicy::advise_focus_lost(WindowInfo const& info)
 {
     CanonicalWindowManagerPolicy::advise_focus_lost(info);
 
-    titlebar_provider->paint_titlebar_for(info.window(), 0x3F);
+    titlebar_provider->paint_titlebar_for(info, 0x3F);
 }
 
 void TitlebarWindowManagerPolicy::advise_focus_gained(WindowInfo const& info)
 {
     CanonicalWindowManagerPolicy::advise_focus_gained(info);
 
-    titlebar_provider->paint_titlebar_for(info.window(), 0xFF);
+    titlebar_provider->paint_titlebar_for(info, 0xFF);
 
     // Frig to force the spinner to the top
     if (auto const spinner_session = spinner.session())
@@ -320,7 +323,7 @@ void TitlebarWindowManagerPolicy::advise_resize(WindowInfo const& window_info, S
 {
     CanonicalWindowManagerPolicy::advise_resize(window_info, new_size);
 
-    titlebar_provider->resize_titlebar_for(window_info.window(), new_size);
+    titlebar_provider->resize_titlebar_for(window_info, new_size);
 }
 
 void TitlebarWindowManagerPolicy::advise_delete_window(WindowInfo const& window_info)
@@ -512,7 +515,7 @@ bool TitlebarWindowManagerPolicy::resize(Window const& window, Point cursor, Poi
     WindowSpecification modifications;
     modifications.top_left() = new_pos;
     modifications.size() = new_size;
-    tools.modify_window(tools.info_for(window), modifications);
+    tools.modify_window(window, modifications);
 
     return true;
 }
